Gives an error measurement for predicted graphs
measure_error.RdThis function compares the predicted graph with the actual and comptues the node and edge error as a proportion
Examples
data(syngraphs)
# Taking the 20th graph as the actual and the 19th graph as predicted.
measure_error(syngraphs[[20]], syngraphs[[19]])